@@ -63,6 +63,24 @@ dev.off()
 
 
 
+# Geom col ----------------------------------------------------------------
+
+png(filename = "inst/geomIcon/www/gg-col.png", bg = "transparent")
+ggplot(data = coord_circle(centre = c(0, 0), r = 1)) + geom_polygon(aes(x = x, y = y), fill = "#BA472D") + coord_fixed() + theme_void()
+p <- ggplot(data.frame(x = c("a", "b"), y = c(10, 20))) + geom_col(mapping = aes(x, y), fill = "white") + theme_void()
+p0 <- ggplot() +
+  geom_segment(aes(x=0, xend=2, y=0, yend=0), size = 2,
+               arrow = arrow(length = unit(0.5, "cm")), color = "white") +
+  geom_segment(aes(x=0, xend=0, y=0, yend=2), size = 2,
+               arrow = arrow(length = unit(0.5, "cm")), color = "white") +
+  theme_void()
+print(p, vp = viewport(width = unit(0.5, "npc"), height = unit(0.5, "npc")))
+dev.off()
+# print(p0, vp = viewport(width = unit(0.6, "npc"), height = unit(0.6, "npc")))
+# ggsave(filename = "www/gg-bar.png")
+
+
+
 
 # Geom line ---------------------------------------------------------------
 
@@ -76,7 +94,7 @@ dev.off()
 
 
 
-# Geom line ---------------------------------------------------------------
+# Geom step ---------------------------------------------------------------
 
 png(filename = "inst/geomIcon/www/gg-step.png", bg = "transparent")
 ggplot(data = coord_circle(centre = c(0, 0), r = 1)) + geom_polygon(aes(x = x, y = y), fill = "#85b6d5") + coord_fixed() + theme_void()
@@ -86,6 +104,16 @@ dev.off()
 
 
 
+# Geom path ---------------------------------------------------------------
+
+png(filename = "inst/geomIcon/www/gg-path.png", bg = "transparent")
+ggplot(data = coord_circle(centre = c(0, 0), r = 1)) + geom_polygon(aes(x = x, y = y), fill = "#7390BC") + coord_fixed() + theme_void()
+p <- ggplot(tail(economics, 100), aes(unemploy/pop, psavert)) + geom_path(color = "white", size = 2) + theme_void()
+print(p, vp = viewport(width = unit(0.6, "npc"), height = unit(0.6, "npc")))
+dev.off()
+
+
+
 
 # Geom density ------------------------------------------------------------
 
@@ -157,7 +185,7 @@ dev.off()
 
 png(filename = "inst/geomIcon/www/gg-violin.png", bg = "transparent")
 ggplot(data = coord_circle(centre = c(0, 0), r = 1)) + geom_polygon(aes(x = x, y = y), fill = "#A9BCF5") + coord_fixed() + theme_void()
-p <- ggplot(data = iris) + 
+p <- ggplot(data = iris) +
   geom_violin(mapping = aes(x = Species, y = Sepal.Width), adjust = .5, color = "black", fill = "white", size = 2) +
   theme_void()
 print(p, vp = viewport(width = unit(0.6, "npc"), height = unit(0.6, "npc")))
@@ -200,20 +228,20 @@ library(dplyr)
 png(filename = "inst/geomIcon/www/gg-sf.png", bg = "transparent")
 world <- rnaturalearth::ne_countries(returnclass = "sf")
 ggplot(data = coord_circle(centre = c(0, 0), r = 1)) + geom_polygon(aes(x = x, y = y), fill = "#FAAC58") + coord_fixed() + theme_void()
-p <- ggplot(data = st_transform(world, 54032)) + 
+p <- ggplot(data = st_transform(world, 54032)) +
   geom_sf(fill = "transparent", color = "white", size = 1.2) + coord_sf(datum = NA) + theme_void()
 print(p, vp = viewport(width = unit(0.9, "npc"), height = unit(0.9, "npc")))
 dev.off()
 
 
-# ggplot(data = filter(world, !continent %in% c("Antarctica", "Seven seas (open ocean)"))) + 
+# ggplot(data = filter(world, !continent %in% c("Antarctica", "Seven seas (open ocean)"))) +
 #   geom_sf() + coord_sf(crs = 102016) + theme_void()
-# ggplot(data = filter(world, !continent %in% c("Antarctica", "Seven seas (open ocean)"))) + 
+# ggplot(data = filter(world, !continent %in% c("Antarctica", "Seven seas (open ocean)"))) +
 #   geom_sf() + coord_sf(crs = 54032, ndiscr = 0) + theme_void()
-# 
-# ggplot(data = st_transform(world, 54030)) + 
+#
+# ggplot(data = st_transform(world, 54030)) +
 #   geom_sf(fill = "transparent", color = "steelblue") + coord_sf(datum = NA) + theme_void()
-# 
+#
 
 
 
@@ -232,7 +260,7 @@ png(filename = "inst/geomIcon/www/gg-area.png", bg = "transparent")
 ggplot(data = coord_circle(centre = c(0, 0), r = 1)) + geom_polygon(aes(x = x, y = y), fill = "#97cbc2") + coord_fixed() + theme_void()
 p <- ggplot(series, aes(time, value)) +
   geom_area(aes(fill = type2)) +
-  # scale_fill_brewer(palette = "Greens", guide = FALSE) + 
+  # scale_fill_brewer(palette = "Greens", guide = FALSE) +
   scale_fill_manual(values = rev(c("#4b668f", "#5586a4", "#6ba4b1", "#80bebe")), guide = FALSE) +
   theme_void()
 print(p, vp = viewport(width = unit(0.6, "npc"), height = unit(0.6, "npc")))
